{ pkgs, config, ... }:
{
  imports = [
    ./common.nix
  ];

  services.gitea-actions-runner = {
    package = pkgs.forgejo-actions-runner;
    instances.default = {
      enable = true;
      name = "fj-hetzner-aarch64";
      url = "https://git.hsn.dev";
      # Obtaining the path to the runner token file may differ
      tokenFile = config.sops.secrets.forgejo-runner-token.path;
      labels = [
        "aarch64"
        "linux"
        "pc"
        "docker-aarch64:docker://node:20-bullseye"
        "native-aarch64:host"
      ];
    };
  };

  sops.secrets."forgejo-runner-token" = {
    # configure secret for the gitea/forgejo runner.
    sopsFile = ./secrets.sops.yaml;
    mode = "0444";
    restartUnits = [ "gitea-runner-default.service" ];
  };

  sops.secrets."cachix/agent_auth_tokens/fj-hetzner-aarch64" = {
    # configure secret for cachix deploy agent.
    sopsFile = ./secrets.sops.yaml;
    mode = "0444";
    restartUnits = [ "cachix-agent.service" ];
  };

  services.cachix-agent = {
    enable = true;
    credentialsFile = config.sops.secrets."cachix/agent_auth_tokens/fj-hetzner-aarch64".path;
  };
}
